@@ -1,6 +1,6 @@
 ;;; Character set conversions
 
-;; Copyright (C) 2004, 2005, 2006 Brailcom, o.p.s.
+;; Copyright (C) 2004, 2005, 2006, 2008 Brailcom, o.p.s.
 
 ;; Author: Milan Zamazal <pdm@brailcom.org>
 
@@ -27,10 +27,18 @@
 (define (recode string from to)
   (with-temp-file-data (tmpfile string)
     (with-temp-file out-tmpfile
-      (system (format nil "iconv -c -f %s -t %s -o %s %s" from to out-tmpfile tmpfile))
+      (system (format nil "iconv -c -f %s -t %s//TRANSLIT -o %s %s" from to out-tmpfile tmpfile))
       (read-file out-tmpfile))))
 
+(defvar recode-special-utf8-translations
+  '(("​" " ")))
+
 (define (recode-utf8->current string)
+  (let ((translations recode-special-utf8-translations))
+    (while translations
+      (let ((translation (car translations)))
+        (set! string (string-replace string (car translation) (cadr translation))))
+      (set! translations (cdr translations))))
   (let ((coding (current-voice-coding)))
     (if (eq? coding 'utf-8)
         string
