@@ -1,6 +1,6 @@
 ;;; Speech Dispatcher interface
 
-;; Copyright (C) 2003, 2004, 2005, 2006 Brailcom, o.p.s.
+;; Copyright (C) 2003, 2004, 2005, 2006, 2007 Brailcom, o.p.s.
 
 ;; Author: Milan Zamazal <pdm@brailcom.org>
 
@@ -45,7 +45,16 @@
          (variant (if (string-matches voice* ".*[0-9]")
                       (substring voice* (- (length voice*) 1) 1)
                       t)))
-    (select-voice* lang gender age variant name)
+    (if (eq? lang t)
+        (begin
+          (voice.select name)
+          (set! voice-select-current-defaults
+                (mapcar (lambda (item)
+                          (if (eq? (car item) 'name)
+                              (list 'name name)
+                              item))
+                        voice-select-defaults)))
+        (select-voice* lang gender age variant name))
     (set! speechd-base-pitch (prosody-get-pitch))
     (restore-prosody)
     (current-voice-coding)))
@@ -168,6 +177,9 @@ punctuation characters), `none' (don't read any punctuation characters) or
 Set voice, which is one of the Speech Dispatcher voice strings."
   (speechd-set-lang-voice nil voice))
 
+(define (speechd-set-festival-voice name)
+  (speechd-set-lang-voice t name))
+
 (define (speechd-set-rate rate)
   "(speechd-set-rate RATE)
 Set speech RATE, which must be a number in the range -100..100."
